<?php

namespace Drupal\Tests\fluent\Functional;

use Drupal\Core\Config\FileStorage;
use Drupal\file\Entity\File;
use Drupal\media\Entity\Media;
use Drupal\node\Entity\Node;
use Drupal\taxonomy\Entity\Term;
use Drupal\Tests\BrowserTestBase;

/**
 * Base functions for Fluent testing.
 *
 * @group fluent
 */
abstract class FluentTestBase extends BrowserTestBase {

  protected $defaultTheme = 'classy';

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    // Modules for core functionality.
    'media',
    'node',
    'block_content',
    'comment',
    'datetime',
    'paragraphs',
    'link',

    // This custom module.
    'fluent_test',
    'fluent',
  ];

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    // Make sure to complete the normal setup steps first.
    parent::setUp();
  }

  /**
   *
   */
  protected function getMediaImage(): Media {
    $media = Media::create(
          [
            'bundle' => 'image',
            'uid' => \Drupal::currentUser()->id(),
            'field_media_image' => [
              'target_id' => $this->getFileImage()->id(),
            ],
          ]
      );
    $media->save();

    return $media;
  }

  /**
   *
   */
  public function getTaxonomyTerm(): Term {
    return Term::create(
          [
            'name' => $this->randomGenerator->string(),
            'vid' => 'tags',
          ]
      );
  }

  /**
   *
   */
  protected function getFileImage(): File {
    $file_data = file_get_contents(
          $this->randomGenerator->image('/tmp/rand.jpg', '200x200', '500x500')
      );

    /**
* @var \Drupal\file\Entity\FileRepository $fileRepo
*/
    $fileRepo = \Drupal::service('file.repository');
    return $fileRepo->writeData($file_data, 'public://' . $this->randomGenerator->string() . '/');
  }

  /**
   *
   */
  protected function getNode(): Node {
    $node = Node::create(
      [
        'type' => 'content_fields',
        'title' => $this->randomGenerator->string(),
        'field_boolean_single' => strval(rand(0, 1)),
        'field_color_single' => ['color' => '#F48668', 'opacity' => round(0+lcg_value()*(abs(1-0)), 2)],
      ]
    );

    $node->save();
    return $node;
  }

}
